Instruction

Enum Instruction 

pub enum Instruction {
Show 14 variants From(FromInstruction), Arg(ArgInstruction), Label(LabelInstruction), Run(RunInstruction), Entrypoint(EntrypointInstruction), Cmd(CmdInstruction), Copy(CopyInstruction), Env(EnvInstruction), Shell(ShellInstruction), Onbuild(OnbuildInstruction), Healthcheck(HealthcheckInstruction), Heredoc(HeredocInstruction), Misc(MiscInstruction), Unknown(SpannedString),
}
A single Dockerfile instruction.

Variants



From(FromInstruction)



Arg(ArgInstruction)



Label(LabelInstruction)



Run(RunInstruction)



Entrypoint(EntrypointInstruction)



Cmd(CmdInstruction)



Copy(CopyInstruction)



Env(EnvInstruction)



Shell(ShellInstruction)



Onbuild(OnbuildInstruction)



Healthcheck(HealthcheckInstruction)



Heredoc(HeredocInstruction)



Misc(MiscInstruction)



Unknown(SpannedString)

A line that could not be parsed as a known instruction. It is kept verbatim so a single malformed line never fails formatting of the file.

Implementations

Source

impl Instruction

pub fn span(&self) -> Span