pub struct BreakableString {
pub span: Span,
pub components: Vec<BreakableStringComponent>,
}Expand description
A Docker string that may be broken across several lines, separated by line
continuations (\\\n), and possibly intermixed with comments.
Fields
span: Spancomponents: Vec<BreakableStringComponent>Trait Implementations
Sourceimpl Clone for BreakableString
impl Clone for BreakableString
Sourcefn clone(&self) -> BreakableString
fn clone(&self) -> BreakableString
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BreakableString
impl Debug for BreakableString
impl Eq for BreakableString
Sourceimpl Ord for BreakableString
impl Ord for BreakableString
Sourcefn cmp(&self, other: &BreakableString) -> Ordering
fn cmp(&self, other: &BreakableString) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BreakableString
impl PartialEq for BreakableString
Sourcefn eq(&self, other: &BreakableString) -> bool
fn eq(&self, other: &BreakableString) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BreakableString
impl PartialOrd for BreakableString
impl StructuralPartialEq for BreakableString