pub struct ShellInstruction {
pub span: Span,
pub expr: ShellOrExecExpr,
}Expand description
A Dockerfile SHELL instruction. Docker only permits the exec (JSON array)
form, but the shell form is tolerated so malformed input still round-trips.
Fields
span: Spanexpr: ShellOrExecExprTrait Implementations
Sourceimpl Clone for ShellInstruction
impl Clone for ShellInstruction
Sourcefn clone(&self) -> ShellInstruction
fn clone(&self) -> ShellInstruction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellInstruction
impl Debug for ShellInstruction
impl Eq for ShellInstruction
Sourceimpl PartialEq for ShellInstruction
impl PartialEq for ShellInstruction
Sourcefn eq(&self, other: &ShellInstruction) -> bool
fn eq(&self, other: &ShellInstruction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ShellInstruction